/* NAMEMOD.C - Created by Dave Humphrey, aj589@freenet.carleton.ca
 *             Oct 1, 1996...
 * Created to modify The Elder Scrolls: Arena computer role playing
 * game created by Bethesda.  Modifies the file NAMES.DAT which
 * contains the names of the savegame files (0-9).  This program
 * modifies this file, changing an empty space into a filled space
 * in order to simplify transfering of savegames.  Simply copy this
 * program into Arena's root directory and run it.  It will only
 * allow modification of empty items in the savegame list.
 */

#include <stdio.h>
#include <string.h>

typedef enum {FALSE, TRUE = 1} boolean;



//========== Display an error message and terminate program
void error_msg(char *message) {
  printf ("/nERROR: %s!/n/n", message);  //Display error message
  exit(FALSE);  //Terminate program
 }
//========== End of procedure error_msg()


//========== Begin main program
int main (void) {
  FILE *f;    //File pointer
  const char filename[20] = "names.dat";  //Name of file containing the savegame data
  char *savename[10];  //Place to save the 10 savegame names...
  int i, j;  //Loop counter
  char ch;  //Input characters
  boolean done = FALSE;  //Loop check

  if ((f = fopen (filename, "rb")) == NULL)    //Open the file
    error_msg("Could not open file");

  for (i = 0; i < 10; i++) {  //Read in all the savegame names in file filename[20]
    if ((savename[i] = (char *) malloc (50)) == NULL)
      error_msg("Could not allocate 50 bytes");

    if (fread(savename[i], 48, 1, f) != 1)
      error_msg("Less than 10 names found in file");
   } //End for loop...

  fclose(f);  //Close the file, done reading names

  printf ("\n\nSuccessfully read savegame name data.");

  do { //Select savegame to modify loop
    printf ("\nTES:ARENA - Savegame Name Data\n\n");

    for (i = 0; i < 10; i++) { //Display savegame names...
      if (strcmp(savename[i], "EMPTY") != 0)
	printf ("(%2d) %-s\n", i, savename[i]);
      else
	printf ("(%2d) -\n", i);
     }

    printf ("\nChoose an empty savegame slot to modify (0-9, ESC): ");

    do { //Wait for user to press # key or ESC
      ch = getch();
    } while ((ch < '0' || ch > '9') && (int)ch != 27);

    if (ch != 27 && strcmp(savename[ch-'0'], "EMPTY") == 0) { //ESC was not pressed and savegame is empty
      printf ("\nEnter name for savegame #%d:", ch-'0');
      scanf ("%40s", savename[ch-'0']);
      done = TRUE;

      if ((f = fopen (filename, "wb")) == NULL)  //Open new file for output
	error_msg ("Could not create file");

      for (i = 0; i < 10; i++) {  //Write 10 savegame names
	fprintf (f, "%-s", savename[i]);

	for (j = strlen(savename[i]); j < 48; j++)  //Pad with character 0
	  fputc (0, f);

       } //End for loop

      fclose(f);  //Close file, done output

      printf ("\nSavegame names file successfully modified and saved.\n\n");
     }
    else if (ch == 27) {  //ESC pressed
      printf ("\nUser interrupt...nothing changed.\n\n");
      done = TRUE;
     }
    else {  //Invalid file was selected
      printf ("\nSavegame #%d is currently occupied!\n", ch-'0');
     }

  } while (!done);  //End main select savegame loop


  for (i = 0; i < 10; i++)  //Delete the malloc'd data
    free (savename[i]);

  return (TRUE); }
//========== End main program